Description Usage Arguments Details
Integration of the logo (as watermark or as is) in ggplot graphics. Important:
The function addLogo should appear immediately after the call to
ggplot (see examples) to embed the logo layer behind the data
and to prevent the logo from overlaying the data.
1 2 |
position |
character; position of the logo (see details) |
alpha |
numeric; transparency of the logo (see |
size |
numeric; values between [0; 1]. A value of 1 corresponds to the maximum possible extension. |
The position may be specified by keywords from the list "default",
"bottomright", "bottom", "bottomleft", "left",
"topleft", "top", "topright", "right", "center"
and "full". Setting "full" corresponds to addLogo(position = "full", size = 1).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.